# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyticsInstance(object):
    """
    Analytics Instance metadata.
    """

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AnalyticsInstance.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the feature_set property of a AnalyticsInstance.
    #: This constant has a value of "SELF_SERVICE_ANALYTICS"
    FEATURE_SET_SELF_SERVICE_ANALYTICS = "SELF_SERVICE_ANALYTICS"

    #: A constant which can be used with the feature_set property of a AnalyticsInstance.
    #: This constant has a value of "ENTERPRISE_ANALYTICS"
    FEATURE_SET_ENTERPRISE_ANALYTICS = "ENTERPRISE_ANALYTICS"

    #: A constant which can be used with the license_type property of a AnalyticsInstance.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_TYPE_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_type property of a AnalyticsInstance.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_TYPE_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyticsInstance object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AnalyticsInstance.
        :type id: str

        :param name:
            The value to assign to the name property of this AnalyticsInstance.
        :type name: str

        :param description:
            The value to assign to the description property of this AnalyticsInstance.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AnalyticsInstance.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AnalyticsInstance.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "INACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param feature_set:
            The value to assign to the feature_set property of this AnalyticsInstance.
            Allowed values for this property are: "SELF_SERVICE_ANALYTICS", "ENTERPRISE_ANALYTICS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type feature_set: str

        :param capacity:
            The value to assign to the capacity property of this AnalyticsInstance.
        :type capacity: oci.analytics.models.Capacity

        :param license_type:
            The value to assign to the license_type property of this AnalyticsInstance.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_type: str

        :param email_notification:
            The value to assign to the email_notification property of this AnalyticsInstance.
        :type email_notification: str

        :param network_endpoint_details:
            The value to assign to the network_endpoint_details property of this AnalyticsInstance.
        :type network_endpoint_details: oci.analytics.models.NetworkEndpointDetails

        :param private_access_channels:
            The value to assign to the private_access_channels property of this AnalyticsInstance.
        :type private_access_channels: dict(str, PrivateAccessChannel)

        :param vanity_url_details:
            The value to assign to the vanity_url_details property of this AnalyticsInstance.
        :type vanity_url_details: dict(str, VanityUrlDetails)

        :param service_url:
            The value to assign to the service_url property of this AnalyticsInstance.
        :type service_url: str

        :param defined_tags:
            The value to assign to the defined_tags property of this AnalyticsInstance.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AnalyticsInstance.
        :type freeform_tags: dict(str, str)

        :param time_created:
            The value to assign to the time_created property of this AnalyticsInstance.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AnalyticsInstance.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'feature_set': 'str',
            'capacity': 'Capacity',
            'license_type': 'str',
            'email_notification': 'str',
            'network_endpoint_details': 'NetworkEndpointDetails',
            'private_access_channels': 'dict(str, PrivateAccessChannel)',
            'vanity_url_details': 'dict(str, VanityUrlDetails)',
            'service_url': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'feature_set': 'featureSet',
            'capacity': 'capacity',
            'license_type': 'licenseType',
            'email_notification': 'emailNotification',
            'network_endpoint_details': 'networkEndpointDetails',
            'private_access_channels': 'privateAccessChannels',
            'vanity_url_details': 'vanityUrlDetails',
            'service_url': 'serviceUrl',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._name = None
        self._description = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._feature_set = None
        self._capacity = None
        self._license_type = None
        self._email_notification = None
        self._network_endpoint_details = None
        self._private_access_channels = None
        self._vanity_url_details = None
        self._service_url = None
        self._defined_tags = None
        self._freeform_tags = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AnalyticsInstance.
        The resource OCID.


        :return: The id of this AnalyticsInstance.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AnalyticsInstance.
        The resource OCID.


        :param id: The id of this AnalyticsInstance.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AnalyticsInstance.
        The name of the Analytics instance. This name must be unique in the tenancy and cannot be changed.


        :return: The name of this AnalyticsInstance.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AnalyticsInstance.
        The name of the Analytics instance. This name must be unique in the tenancy and cannot be changed.


        :param name: The name of this AnalyticsInstance.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this AnalyticsInstance.
        Optional description.


        :return: The description of this AnalyticsInstance.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AnalyticsInstance.
        Optional description.


        :param description: The description of this AnalyticsInstance.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AnalyticsInstance.
        The OCID of the compartment.


        :return: The compartment_id of this AnalyticsInstance.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AnalyticsInstance.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this AnalyticsInstance.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AnalyticsInstance.
        The current state of an instance.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "INACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AnalyticsInstance.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AnalyticsInstance.
        The current state of an instance.


        :param lifecycle_state: The lifecycle_state of this AnalyticsInstance.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "INACTIVE", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def feature_set(self):
        """
        **[Required]** Gets the feature_set of this AnalyticsInstance.
        Analytics feature set.

        Allowed values for this property are: "SELF_SERVICE_ANALYTICS", "ENTERPRISE_ANALYTICS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The feature_set of this AnalyticsInstance.
        :rtype: str
        """
        return self._feature_set

    @feature_set.setter
    def feature_set(self, feature_set):
        """
        Sets the feature_set of this AnalyticsInstance.
        Analytics feature set.


        :param feature_set: The feature_set of this AnalyticsInstance.
        :type: str
        """
        allowed_values = ["SELF_SERVICE_ANALYTICS", "ENTERPRISE_ANALYTICS"]
        if not value_allowed_none_or_none_sentinel(feature_set, allowed_values):
            feature_set = 'UNKNOWN_ENUM_VALUE'
        self._feature_set = feature_set

    @property
    def capacity(self):
        """
        **[Required]** Gets the capacity of this AnalyticsInstance.

        :return: The capacity of this AnalyticsInstance.
        :rtype: oci.analytics.models.Capacity
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """
        Sets the capacity of this AnalyticsInstance.

        :param capacity: The capacity of this AnalyticsInstance.
        :type: oci.analytics.models.Capacity
        """
        self._capacity = capacity

    @property
    def license_type(self):
        """
        Gets the license_type of this AnalyticsInstance.
        The license used for the service.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_type of this AnalyticsInstance.
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """
        Sets the license_type of this AnalyticsInstance.
        The license used for the service.


        :param license_type: The license_type of this AnalyticsInstance.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_type, allowed_values):
            license_type = 'UNKNOWN_ENUM_VALUE'
        self._license_type = license_type

    @property
    def email_notification(self):
        """
        Gets the email_notification of this AnalyticsInstance.
        Email address receiving notifications.


        :return: The email_notification of this AnalyticsInstance.
        :rtype: str
        """
        return self._email_notification

    @email_notification.setter
    def email_notification(self, email_notification):
        """
        Sets the email_notification of this AnalyticsInstance.
        Email address receiving notifications.


        :param email_notification: The email_notification of this AnalyticsInstance.
        :type: str
        """
        self._email_notification = email_notification

    @property
    def network_endpoint_details(self):
        """
        **[Required]** Gets the network_endpoint_details of this AnalyticsInstance.

        :return: The network_endpoint_details of this AnalyticsInstance.
        :rtype: oci.analytics.models.NetworkEndpointDetails
        """
        return self._network_endpoint_details

    @network_endpoint_details.setter
    def network_endpoint_details(self, network_endpoint_details):
        """
        Sets the network_endpoint_details of this AnalyticsInstance.

        :param network_endpoint_details: The network_endpoint_details of this AnalyticsInstance.
        :type: oci.analytics.models.NetworkEndpointDetails
        """
        self._network_endpoint_details = network_endpoint_details

    @property
    def private_access_channels(self):
        """
        Gets the private_access_channels of this AnalyticsInstance.
        Map of PrivateAccessChannel unique identifier key as KEY and PrivateAccessChannel Object as VALUE.


        :return: The private_access_channels of this AnalyticsInstance.
        :rtype: dict(str, PrivateAccessChannel)
        """
        return self._private_access_channels

    @private_access_channels.setter
    def private_access_channels(self, private_access_channels):
        """
        Sets the private_access_channels of this AnalyticsInstance.
        Map of PrivateAccessChannel unique identifier key as KEY and PrivateAccessChannel Object as VALUE.


        :param private_access_channels: The private_access_channels of this AnalyticsInstance.
        :type: dict(str, PrivateAccessChannel)
        """
        self._private_access_channels = private_access_channels

    @property
    def vanity_url_details(self):
        """
        Gets the vanity_url_details of this AnalyticsInstance.
        Map of VanityUrl unique identifier key as KEY and VanityUrl Object as VALUE.


        :return: The vanity_url_details of this AnalyticsInstance.
        :rtype: dict(str, VanityUrlDetails)
        """
        return self._vanity_url_details

    @vanity_url_details.setter
    def vanity_url_details(self, vanity_url_details):
        """
        Sets the vanity_url_details of this AnalyticsInstance.
        Map of VanityUrl unique identifier key as KEY and VanityUrl Object as VALUE.


        :param vanity_url_details: The vanity_url_details of this AnalyticsInstance.
        :type: dict(str, VanityUrlDetails)
        """
        self._vanity_url_details = vanity_url_details

    @property
    def service_url(self):
        """
        Gets the service_url of this AnalyticsInstance.
        URL of the Analytics service.


        :return: The service_url of this AnalyticsInstance.
        :rtype: str
        """
        return self._service_url

    @service_url.setter
    def service_url(self, service_url):
        """
        Sets the service_url of this AnalyticsInstance.
        URL of the Analytics service.


        :param service_url: The service_url of this AnalyticsInstance.
        :type: str
        """
        self._service_url = service_url

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AnalyticsInstance.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AnalyticsInstance.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AnalyticsInstance.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AnalyticsInstance.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AnalyticsInstance.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AnalyticsInstance.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AnalyticsInstance.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AnalyticsInstance.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AnalyticsInstance.
        The date and time the instance was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this AnalyticsInstance.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AnalyticsInstance.
        The date and time the instance was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this AnalyticsInstance.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this AnalyticsInstance.
        The date and time the instance was last updated (in the format defined by RFC3339).
        This timestamp represents updates made through this API. External events do not
        influence it.


        :return: The time_updated of this AnalyticsInstance.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AnalyticsInstance.
        The date and time the instance was last updated (in the format defined by RFC3339).
        This timestamp represents updates made through this API. External events do not
        influence it.


        :param time_updated: The time_updated of this AnalyticsInstance.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .configuration_source_provider import ConfigurationSourceProvider
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GitlabAccessTokenConfigurationSourceProvider(ConfigurationSourceProvider):
    """
    The properties that define a configuration source provider of the type `GITLAB_ACCESS_TOKEN`.
    This type corresponds to a configuration source provider in GitLab that is authenticated with a personal access token.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GitlabAccessTokenConfigurationSourceProvider object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.GitlabAccessTokenConfigurationSourceProvider.config_source_provider_type` attribute
        of this class is ``GITLAB_ACCESS_TOKEN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this GitlabAccessTokenConfigurationSourceProvider.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this GitlabAccessTokenConfigurationSourceProvider.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this GitlabAccessTokenConfigurationSourceProvider.
        :type display_name: str

        :param description:
            The value to assign to the description property of this GitlabAccessTokenConfigurationSourceProvider.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this GitlabAccessTokenConfigurationSourceProvider.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this GitlabAccessTokenConfigurationSourceProvider.
            Allowed values for this property are: "ACTIVE"
        :type lifecycle_state: str

        :param config_source_provider_type:
            The value to assign to the config_source_provider_type property of this GitlabAccessTokenConfigurationSourceProvider.
            Allowed values for this property are: "GITLAB_ACCESS_TOKEN", "GITHUB_ACCESS_TOKEN"
        :type config_source_provider_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this GitlabAccessTokenConfigurationSourceProvider.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this GitlabAccessTokenConfigurationSourceProvider.
        :type defined_tags: dict(str, dict(str, object))

        :param api_endpoint:
            The value to assign to the api_endpoint property of this GitlabAccessTokenConfigurationSourceProvider.
        :type api_endpoint: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'config_source_provider_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'api_endpoint': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'config_source_provider_type': 'configSourceProviderType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'api_endpoint': 'apiEndpoint'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._time_created = None
        self._lifecycle_state = None
        self._config_source_provider_type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._api_endpoint = None
        self._config_source_provider_type = 'GITLAB_ACCESS_TOKEN'

    @property
    def api_endpoint(self):
        """
        Gets the api_endpoint of this GitlabAccessTokenConfigurationSourceProvider.
        The Git service endpoint.
        Example: `https://gitlab.com`


        :return: The api_endpoint of this GitlabAccessTokenConfigurationSourceProvider.
        :rtype: str
        """
        return self._api_endpoint

    @api_endpoint.setter
    def api_endpoint(self, api_endpoint):
        """
        Sets the api_endpoint of this GitlabAccessTokenConfigurationSourceProvider.
        The Git service endpoint.
        Example: `https://gitlab.com`


        :param api_endpoint: The api_endpoint of this GitlabAccessTokenConfigurationSourceProvider.
        :type: str
        """
        self._api_endpoint = api_endpoint

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestResource(object):
    """
    A resource that is created or operated on by an asynchronous operation that is tracked by a work request.
    """

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "CREATED"
    ACTION_TYPE_CREATED = "CREATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "UPDATED"
    ACTION_TYPE_UPDATED = "UPDATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "DELETED"
    ACTION_TYPE_DELETED = "DELETED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "IN_PROGRESS"
    ACTION_TYPE_IN_PROGRESS = "IN_PROGRESS"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this WorkRequestResource.
        :type entity_type: str

        :param action_type:
            The value to assign to the action_type property of this WorkRequestResource.
            Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_type: str

        :param identifier:
            The value to assign to the identifier property of this WorkRequestResource.
        :type identifier: str

        :param entity_uri:
            The value to assign to the entity_uri property of this WorkRequestResource.
        :type entity_uri: str

        """
        self.swagger_types = {
            'entity_type': 'str',
            'action_type': 'str',
            'identifier': 'str',
            'entity_uri': 'str'
        }

        self.attribute_map = {
            'entity_type': 'entityType',
            'action_type': 'actionType',
            'identifier': 'identifier',
            'entity_uri': 'entityUri'
        }

        self._entity_type = None
        self._action_type = None
        self._identifier = None
        self._entity_uri = None

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this WorkRequestResource.
        The resource type impacted by the work request.


        :return: The entity_type of this WorkRequestResource.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this WorkRequestResource.
        The resource type impacted by the work request.


        :param entity_type: The entity_type of this WorkRequestResource.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def action_type(self):
        """
        **[Required]** Gets the action_type of this WorkRequestResource.
        The way in which this resource was affected by the operation that spawned the work request.
        A resource being created, updated, or deleted will remain in the IN_PROGRESS state until
        work is complete for that resource at which point it will transition to CREATED, UPDATED,
        or DELETED, respectively.

        Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_type of this WorkRequestResource.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this WorkRequestResource.
        The way in which this resource was affected by the operation that spawned the work request.
        A resource being created, updated, or deleted will remain in the IN_PROGRESS state until
        work is complete for that resource at which point it will transition to CREATED, UPDATED,
        or DELETED, respectively.


        :param action_type: The action_type of this WorkRequestResource.
        :type: str
        """
        allowed_values = ["CREATED", "UPDATED", "DELETED", "IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(action_type, allowed_values):
            action_type = 'UNKNOWN_ENUM_VALUE'
        self._action_type = action_type

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this WorkRequestResource.
        An OCID or other unique identifier for the resource.


        :return: The identifier of this WorkRequestResource.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this WorkRequestResource.
        An OCID or other unique identifier for the resource.


        :param identifier: The identifier of this WorkRequestResource.
        :type: str
        """
        self._identifier = identifier

    @property
    def entity_uri(self):
        """
        Gets the entity_uri of this WorkRequestResource.
        The URI path that the user can use for a GET request to access the resource metadata.


        :return: The entity_uri of this WorkRequestResource.
        :rtype: str
        """
        return self._entity_uri

    @entity_uri.setter
    def entity_uri(self, entity_uri):
        """
        Sets the entity_uri of this WorkRequestResource.
        The URI path that the user can use for a GET request to access the resource metadata.


        :param entity_uri: The entity_uri of this WorkRequestResource.
        :type: str
        """
        self._entity_uri = entity_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EnableHostInsightDetails(object):
    """
    The information about the host to be analyzed.
    """

    #: A constant which can be used with the entity_source property of a EnableHostInsightDetails.
    #: This constant has a value of "MACS_MANAGED_EXTERNAL_HOST"
    ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_HOST = "MACS_MANAGED_EXTERNAL_HOST"

    def __init__(self, **kwargs):
        """
        Initializes a new EnableHostInsightDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.EnableMacsManagedExternalHostInsightDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this EnableHostInsightDetails.
            Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST"
        :type entity_source: str

        """
        self.swagger_types = {
            'entity_source': 'str'
        }

        self.attribute_map = {
            'entity_source': 'entitySource'
        }

        self._entity_source = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entitySource']

        if type == 'MACS_MANAGED_EXTERNAL_HOST':
            return 'EnableMacsManagedExternalHostInsightDetails'
        else:
            return 'EnableHostInsightDetails'

    @property
    def entity_source(self):
        """
        **[Required]** Gets the entity_source of this EnableHostInsightDetails.
        Source of the host entity.

        Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST"


        :return: The entity_source of this EnableHostInsightDetails.
        :rtype: str
        """
        return self._entity_source

    @entity_source.setter
    def entity_source(self, entity_source):
        """
        Sets the entity_source of this EnableHostInsightDetails.
        Source of the host entity.


        :param entity_source: The entity_source of this EnableHostInsightDetails.
        :type: str
        """
        allowed_values = ["MACS_MANAGED_EXTERNAL_HOST"]
        if not value_allowed_none_or_none_sentinel(entity_source, allowed_values):
            raise ValueError(
                "Invalid value for `entity_source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._entity_source = entity_source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostHardwareConfiguration(HostConfigurationMetricGroup):
    """
    Hardware Configuration metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostHardwareConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostHardwareConfiguration.metric_name` attribute
        of this class is ``HOST_HARDWARE_CONFIGURATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostHardwareConfiguration.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostHardwareConfiguration.
        :type time_collected: datetime

        :param cpu_architecture:
            The value to assign to the cpu_architecture property of this HostHardwareConfiguration.
        :type cpu_architecture: str

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'cpu_architecture': 'str'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'cpu_architecture': 'cpuArchitecture'
        }

        self._metric_name = None
        self._time_collected = None
        self._cpu_architecture = None
        self._metric_name = 'HOST_HARDWARE_CONFIGURATION'

    @property
    def cpu_architecture(self):
        """
        **[Required]** Gets the cpu_architecture of this HostHardwareConfiguration.
        Processor architecture used by the platform


        :return: The cpu_architecture of this HostHardwareConfiguration.
        :rtype: str
        """
        return self._cpu_architecture

    @cpu_architecture.setter
    def cpu_architecture(self, cpu_architecture):
        """
        Sets the cpu_architecture of this HostHardwareConfiguration.
        Processor architecture used by the platform


        :param cpu_architecture: The cpu_architecture of this HostHardwareConfiguration.
        :type: str
        """
        self._cpu_architecture = cpu_architecture

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WarningReferenceDetails(object):
    """
    A list of LogAnalyticsWarning references.  Used as input to APIs which operate on a
    list.  For example, the suppress warning API accepts a list of warning references
    and will suppress all warnings in the input list.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WarningReferenceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param warning_references:
            The value to assign to the warning_references property of this WarningReferenceDetails.
        :type warning_references: list[str]

        """
        self.swagger_types = {
            'warning_references': 'list[str]'
        }

        self.attribute_map = {
            'warning_references': 'warningReferences'
        }

        self._warning_references = None

    @property
    def warning_references(self):
        """
        Gets the warning_references of this WarningReferenceDetails.
        A list of LogAnalyticsWarning references.  Used as input to APIs which operate on a
        list.  For example, the suppress warning API accepts a list of warning references
        and will suppress all warnings in the input list.


        :return: The warning_references of this WarningReferenceDetails.
        :rtype: list[str]
        """
        return self._warning_references

    @warning_references.setter
    def warning_references(self, warning_references):
        """
        Sets the warning_references of this WarningReferenceDetails.
        A list of LogAnalyticsWarning references.  Used as input to APIs which operate on a
        list.  For example, the suppress warning API accepts a list of warning references
        and will suppress all warnings in the input list.


        :param warning_references: The warning_references of this WarningReferenceDetails.
        :type: list[str]
        """
        self._warning_references = warning_references

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class GoldenGateClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.golden_gate.GoldenGateClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new GoldenGateClientCompositeOperations object

        :param GoldenGateClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_database_registration_compartment_and_wait_for_state(self, database_registration_id, change_database_registration_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.change_database_registration_compartment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str database_registration_id: (required)
            A unique DatabaseRegistration identifier.

        :param oci.golden_gate.models.ChangeDatabaseRegistrationCompartmentDetails change_database_registration_compartment_details: (required)
            Properties to change the compartment of a DatabaseRegistration.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.change_database_registration_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_database_registration_compartment(database_registration_id, change_database_registration_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_deployment_compartment_and_wait_for_state(self, deployment_id, change_deployment_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.change_deployment_compartment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param oci.golden_gate.models.ChangeDeploymentCompartmentDetails change_deployment_compartment_details: (required)
            Properties to change the compartment of a Deployment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.change_deployment_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_deployment_compartment(deployment_id, change_deployment_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_database_registration_and_wait_for_state(self, create_database_registration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.create_database_registration` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param oci.golden_gate.models.CreateDatabaseRegistrationDetails create_database_registration_details: (required)
            Specification of the DatabaseRegistration to create.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.create_database_registration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_database_registration(create_database_registration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_deployment_and_wait_for_state(self, create_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.create_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param oci.golden_gate.models.CreateDeploymentDetails create_deployment_details: (required)
            Specifications to create the Deployment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.create_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_deployment(create_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_deployment_backup_and_wait_for_state(self, create_deployment_backup_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.create_deployment_backup` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param oci.golden_gate.models.CreateDeploymentBackupDetails create_deployment_backup_details: (required)
            Specification of the DeploymentBackup to create.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.create_deployment_backup`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_deployment_backup(create_deployment_backup_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_database_registration_and_wait_for_state(self, database_registration_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.delete_database_registration` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str database_registration_id: (required)
            A unique DatabaseRegistration identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.delete_database_registration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_database_registration(database_registration_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_deployment_and_wait_for_state(self, deployment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.delete_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.delete_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_deployment(deployment_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_deployment_backup_and_wait_for_state(self, deployment_backup_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.delete_deployment_backup` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_backup_id: (required)
            A unique DeploymentBackup identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.delete_deployment_backup`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_deployment_backup(deployment_backup_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def restore_deployment_and_wait_for_state(self, deployment_backup_id, restore_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.restore_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_backup_id: (required)
            A unique DeploymentBackup identifier.

        :param oci.golden_gate.models.RestoreDeploymentDetails restore_deployment_details: (required)
            A placeholder for any additional metadata to describe the deployment restore.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.restore_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.restore_deployment(deployment_backup_id, restore_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def start_deployment_and_wait_for_state(self, deployment_id, start_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.start_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param oci.golden_gate.models.StartDeploymentDetails start_deployment_details: (required)
            A placeholder for any additional metadata to describe the deployment start.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.start_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.start_deployment(deployment_id, start_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def stop_deployment_and_wait_for_state(self, deployment_id, stop_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.stop_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param oci.golden_gate.models.StopDeploymentDetails stop_deployment_details: (required)
            A placeholder for any additional metadata to describe the deployment stop.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.stop_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.stop_deployment(deployment_id, stop_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_database_registration_and_wait_for_state(self, database_registration_id, update_database_registration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.update_database_registration` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str database_registration_id: (required)
            A unique DatabaseRegistration identifier.

        :param oci.golden_gate.models.UpdateDatabaseRegistrationDetails update_database_registration_details: (required)
            The new DatabaseRegistration specifications to apply.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.update_database_registration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_database_registration(database_registration_id, update_database_registration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_deployment_and_wait_for_state(self, deployment_id, update_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.update_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param oci.golden_gate.models.UpdateDeploymentDetails update_deployment_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.update_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_deployment(deployment_id, update_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_deployment_backup_and_wait_for_state(self, deployment_backup_id, update_deployment_backup_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.update_deployment_backup` and waits for the :py:class:`~oci.golden_gate.models.DeploymentBackup` acted upon
        to enter the given state(s).

        :param str deployment_backup_id: (required)
            A unique DeploymentBackup identifier.

        :param oci.golden_gate.models.UpdateDeploymentBackupDetails update_deployment_backup_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.DeploymentBackup.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.update_deployment_backup`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_deployment_backup(deployment_backup_id, update_deployment_backup_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_deployment_backup(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def upgrade_deployment_and_wait_for_state(self, deployment_id, upgrade_deployment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.golden_gate.GoldenGateClient.upgrade_deployment` and waits for the :py:class:`~oci.golden_gate.models.WorkRequest`
        to enter the given state(s).

        :param str deployment_id: (required)
            A unique Deployment identifier.

        :param oci.golden_gate.models.UpgradeDeploymentDetails upgrade_deployment_details: (required)
            A placeholder for any additional metadata to describe the deployment upgrade.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.golden_gate.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.golden_gate.GoldenGateClient.upgrade_deployment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.upgrade_deployment(deployment_id, upgrade_deployment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_read_attribute import AbstractReadAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BiccReadAttributes(AbstractReadAttribute):
    """
    Properties to configure reading from an Oracle Database.
    """

    #: A constant which can be used with the extract_strategy property of a BiccReadAttributes.
    #: This constant has a value of "FULL"
    EXTRACT_STRATEGY_FULL = "FULL"

    #: A constant which can be used with the extract_strategy property of a BiccReadAttributes.
    #: This constant has a value of "INCREMENTAL"
    EXTRACT_STRATEGY_INCREMENTAL = "INCREMENTAL"

    def __init__(self, **kwargs):
        """
        Initializes a new BiccReadAttributes object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.BiccReadAttributes.model_type` attribute
        of this class is ``BICC_READ_ATTRIBUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this BiccReadAttributes.
            Allowed values for this property are: "ORACLEREADATTRIBUTE", "ORACLE_READ_ATTRIBUTE", "BICC_READ_ATTRIBUTE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param fetch_size:
            The value to assign to the fetch_size property of this BiccReadAttributes.
        :type fetch_size: int

        :param extract_strategy:
            The value to assign to the extract_strategy property of this BiccReadAttributes.
            Allowed values for this property are: "FULL", "INCREMENTAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type extract_strategy: str

        :param external_storage:
            The value to assign to the external_storage property of this BiccReadAttributes.
        :type external_storage: oci.data_integration.models.ExternalStorage

        :param initial_extract_date:
            The value to assign to the initial_extract_date property of this BiccReadAttributes.
        :type initial_extract_date: datetime

        :param last_extract_date:
            The value to assign to the last_extract_date property of this BiccReadAttributes.
        :type last_extract_date: datetime

        """
        self.swagger_types = {
            'model_type': 'str',
            'fetch_size': 'int',
            'extract_strategy': 'str',
            'external_storage': 'ExternalStorage',
            'initial_extract_date': 'datetime',
            'last_extract_date': 'datetime'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'fetch_size': 'fetchSize',
            'extract_strategy': 'extractStrategy',
            'external_storage': 'externalStorage',
            'initial_extract_date': 'initialExtractDate',
            'last_extract_date': 'lastExtractDate'
        }

        self._model_type = None
        self._fetch_size = None
        self._extract_strategy = None
        self._external_storage = None
        self._initial_extract_date = None
        self._last_extract_date = None
        self._model_type = 'BICC_READ_ATTRIBUTE'

    @property
    def fetch_size(self):
        """
        Gets the fetch_size of this BiccReadAttributes.
        The fetch size for reading.


        :return: The fetch_size of this BiccReadAttributes.
        :rtype: int
        """
        return self._fetch_size

    @fetch_size.setter
    def fetch_size(self, fetch_size):
        """
        Sets the fetch_size of this BiccReadAttributes.
        The fetch size for reading.


        :param fetch_size: The fetch_size of this BiccReadAttributes.
        :type: int
        """
        self._fetch_size = fetch_size

    @property
    def extract_strategy(self):
        """
        Gets the extract_strategy of this BiccReadAttributes.
        Extraction Strategy - FULL|INCREMENTAL

        Allowed values for this property are: "FULL", "INCREMENTAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The extract_strategy of this BiccReadAttributes.
        :rtype: str
        """
        return self._extract_strategy

    @extract_strategy.setter
    def extract_strategy(self, extract_strategy):
        """
        Sets the extract_strategy of this BiccReadAttributes.
        Extraction Strategy - FULL|INCREMENTAL


        :param extract_strategy: The extract_strategy of this BiccReadAttributes.
        :type: str
        """
        allowed_values = ["FULL", "INCREMENTAL"]
        if not value_allowed_none_or_none_sentinel(extract_strategy, allowed_values):
            extract_strategy = 'UNKNOWN_ENUM_VALUE'
        self._extract_strategy = extract_strategy

    @property
    def external_storage(self):
        """
        Gets the external_storage of this BiccReadAttributes.

        :return: The external_storage of this BiccReadAttributes.
        :rtype: oci.data_integration.models.ExternalStorage
        """
        return self._external_storage

    @external_storage.setter
    def external_storage(self, external_storage):
        """
        Sets the external_storage of this BiccReadAttributes.

        :param external_storage: The external_storage of this BiccReadAttributes.
        :type: oci.data_integration.models.ExternalStorage
        """
        self._external_storage = external_storage

    @property
    def initial_extract_date(self):
        """
        Gets the initial_extract_date of this BiccReadAttributes.
        Date from where extract should start


        :return: The initial_extract_date of this BiccReadAttributes.
        :rtype: datetime
        """
        return self._initial_extract_date

    @initial_extract_date.setter
    def initial_extract_date(self, initial_extract_date):
        """
        Sets the initial_extract_date of this BiccReadAttributes.
        Date from where extract should start


        :param initial_extract_date: The initial_extract_date of this BiccReadAttributes.
        :type: datetime
        """
        self._initial_extract_date = initial_extract_date

    @property
    def last_extract_date(self):
        """
        Gets the last_extract_date of this BiccReadAttributes.
        Date last extracted


        :return: The last_extract_date of this BiccReadAttributes.
        :rtype: datetime
        """
        return self._last_extract_date

    @last_extract_date.setter
    def last_extract_date(self, last_extract_date):
        """
        Sets the last_extract_date of this BiccReadAttributes.
        Date last extracted


        :param last_extract_date: The last_extract_date of this BiccReadAttributes.
        :type: datetime
        """
        self._last_extract_date = last_extract_date

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateVnicDetails(object):
    """
    Contains properties for a VNIC. You use this object when creating the
    primary VNIC during instance launch or when creating a secondary VNIC.
    For more information about VNICs, see
    `Virtual Network Interface Cards (VNICs)`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateVnicDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param assign_public_ip:
            The value to assign to the assign_public_ip property of this CreateVnicDetails.
        :type assign_public_ip: bool

        :param assign_private_dns_record:
            The value to assign to the assign_private_dns_record property of this CreateVnicDetails.
        :type assign_private_dns_record: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateVnicDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateVnicDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateVnicDetails.
        :type freeform_tags: dict(str, str)

        :param hostname_label:
            The value to assign to the hostname_label property of this CreateVnicDetails.
        :type hostname_label: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateVnicDetails.
        :type nsg_ids: list[str]

        :param private_ip:
            The value to assign to the private_ip property of this CreateVnicDetails.
        :type private_ip: str

        :param skip_source_dest_check:
            The value to assign to the skip_source_dest_check property of this CreateVnicDetails.
        :type skip_source_dest_check: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateVnicDetails.
        :type subnet_id: str

        :param vlan_id:
            The value to assign to the vlan_id property of this CreateVnicDetails.
        :type vlan_id: str

        """
        self.swagger_types = {
            'assign_public_ip': 'bool',
            'assign_private_dns_record': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'hostname_label': 'str',
            'nsg_ids': 'list[str]',
            'private_ip': 'str',
            'skip_source_dest_check': 'bool',
            'subnet_id': 'str',
            'vlan_id': 'str'
        }

        self.attribute_map = {
            'assign_public_ip': 'assignPublicIp',
            'assign_private_dns_record': 'assignPrivateDnsRecord',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'hostname_label': 'hostnameLabel',
            'nsg_ids': 'nsgIds',
            'private_ip': 'privateIp',
            'skip_source_dest_check': 'skipSourceDestCheck',
            'subnet_id': 'subnetId',
            'vlan_id': 'vlanId'
        }

        self._assign_public_ip = None
        self._assign_private_dns_record = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._hostname_label = None
        self._nsg_ids = None
        self._private_ip = None
        self._skip_source_dest_check = None
        self._subnet_id = None
        self._vlan_id = None

    @property
    def assign_public_ip(self):
        """
        Gets the assign_public_ip of this CreateVnicDetails.
        Whether the VNIC should be assigned a public IP address. Defaults to whether
        the subnet is public or private. If not set and the VNIC is being created
        in a private subnet (that is, where `prohibitPublicIpOnVnic` = true in the
        :class:`Subnet`), then no public IP address is assigned.
        If not set and the subnet is public (`prohibitPublicIpOnVnic` = false), then
        a public IP address is assigned. If set to true and
        `prohibitPublicIpOnVnic` = true, an error is returned.

        **Note:** This public IP address is associated with the primary private IP
        on the VNIC. For more information, see
        `IP Addresses`__.

        **Note:** There's a limit to the number of :class:`PublicIp`
        a VNIC or instance can have. If you try to create a secondary VNIC
        with an assigned public IP for an instance that has already
        reached its public IP limit, an error is returned. For information
        about the public IP limits, see
        `Public IP Addresses`__.

        Example: `false`

        If you specify a `vlanId`, then `assignPublicIp` must be set to false. See
        :class:`Vlan`.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm


        :return: The assign_public_ip of this CreateVnicDetails.
        :rtype: bool
        """
        return self._assign_public_ip

    @assign_public_ip.setter
    def assign_public_ip(self, assign_public_ip):
        """
        Sets the assign_public_ip of this CreateVnicDetails.
        Whether the VNIC should be assigned a public IP address. Defaults to whether
        the subnet is public or private. If not set and the VNIC is being created
        in a private subnet (that is, where `prohibitPublicIpOnVnic` = true in the
        :class:`Subnet`), then no public IP address is assigned.
        If not set and the subnet is public (`prohibitPublicIpOnVnic` = false), then
        a public IP address is assigned. If set to true and
        `prohibitPublicIpOnVnic` = true, an error is returned.

        **Note:** This public IP address is associated with the primary private IP
        on the VNIC. For more information, see
        `IP Addresses`__.

        **Note:** There's a limit to the number of :class:`PublicIp`
        a VNIC or instance can have. If you try to create a secondary VNIC
        with an assigned public IP for an instance that has already
        reached its public IP limit, an error is returned. For information
        about the public IP limits, see
        `Public IP Addresses`__.

        Example: `false`

        If you specify a `vlanId`, then `assignPublicIp` must be set to false. See
        :class:`Vlan`.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm


        :param assign_public_ip: The assign_public_ip of this CreateVnicDetails.
        :type: bool
        """
        self._assign_public_ip = assign_public_ip

    @property
    def assign_private_dns_record(self):
        """
        Gets the assign_private_dns_record of this CreateVnicDetails.
        Whether the VNIC should be assigned a DNS record. If set to false, there will be no DNS record
        registration for the VNIC. If set to true, the DNS record will be registered. The default
        value is true.

        If you specify a `hostnameLabel`, then `assignPrivateDnsRecord` must be set to true.


        :return: The assign_private_dns_record of this CreateVnicDetails.
        :rtype: bool
        """
        return self._assign_private_dns_record

    @assign_private_dns_record.setter
    def assign_private_dns_record(self, assign_private_dns_record):
        """
        Sets the assign_private_dns_record of this CreateVnicDetails.
        Whether the VNIC should be assigned a DNS record. If set to false, there will be no DNS record
        registration for the VNIC. If set to true, the DNS record will be registered. The default
        value is true.

        If you specify a `hostnameLabel`, then `assignPrivateDnsRecord` must be set to true.


        :param assign_private_dns_record: The assign_private_dns_record of this CreateVnicDetails.
        :type: bool
        """
        self._assign_private_dns_record = assign_private_dns_record

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateVnicDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateVnicDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateVnicDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateVnicDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateVnicDetails.
        A user-friendly name for the VNIC. Does not have to be unique.
        Avoid entering confidential information.


        :return: The display_name of this CreateVnicDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateVnicDetails.
        A user-friendly name for the VNIC. Does not have to be unique.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateVnicDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateVnicDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateVnicDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateVnicDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateVnicDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def hostname_label(self):
        """
        Gets the hostname_label of this CreateVnicDetails.
        The hostname for the VNIC's primary private IP. Used for DNS. The value is the hostname
        portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, `bminstance-1` in FQDN `bminstance-1.subnet123.vcn1.oraclevcn.com`).
        Must be unique across all VNICs in the subnet and comply with
        `RFC 952`__ and
        `RFC 1123`__.
        The value appears in the :class:`Vnic` object and also the
        :class:`PrivateIp` object returned by
        :func:`list_private_ips` and
        :func:`get_private_ip`.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        When launching an instance, use this `hostnameLabel` instead
        of the deprecated `hostnameLabel` in
        :func:`launch_instance_details`.
        If you provide both, the values must match.

        Example: `bminstance-1`

        If you specify a `vlanId`, the `hostnameLabel` cannot be specified. VNICs on a VLAN
        can not be assigned a hostname. See :class:`Vlan`.

        __ https://tools.ietf.org/html/rfc952
        __ https://tools.ietf.org/html/rfc1123
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm


        :return: The hostname_label of this CreateVnicDetails.
        :rtype: str
        """
        return self._hostname_label

    @hostname_label.setter
    def hostname_label(self, hostname_label):
        """
        Sets the hostname_label of this CreateVnicDetails.
        The hostname for the VNIC's primary private IP. Used for DNS. The value is the hostname
        portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, `bminstance-1` in FQDN `bminstance-1.subnet123.vcn1.oraclevcn.com`).
        Must be unique across all VNICs in the subnet and comply with
        `RFC 952`__ and
        `RFC 1123`__.
        The value appears in the :class:`Vnic` object and also the
        :class:`PrivateIp` object returned by
        :func:`list_private_ips` and
        :func:`get_private_ip`.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        When launching an instance, use this `hostnameLabel` instead
        of the deprecated `hostnameLabel` in
        :func:`launch_instance_details`.
        If you provide both, the values must match.

        Example: `bminstance-1`

        If you specify a `vlanId`, the `hostnameLabel` cannot be specified. VNICs on a VLAN
        can not be assigned a hostname. See :class:`Vlan`.

        __ https://tools.ietf.org/html/rfc952
        __ https://tools.ietf.org/html/rfc1123
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm


        :param hostname_label: The hostname_label of this CreateVnicDetails.
        :type: str
        """
        self._hostname_label = hostname_label

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateVnicDetails.
        A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.

        If a `vlanId` is specified, the `nsgIds` cannot be specified. The `vlanId`
        indicates that the VNIC will belong to a VLAN instead of a subnet. With VLANs,
        all VNICs in the VLAN belong to the NSGs that are associated with the VLAN.
        See :class:`Vlan`.


        :return: The nsg_ids of this CreateVnicDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateVnicDetails.
        A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.

        If a `vlanId` is specified, the `nsgIds` cannot be specified. The `vlanId`
        indicates that the VNIC will belong to a VLAN instead of a subnet. With VLANs,
        all VNICs in the VLAN belong to the NSGs that are associated with the VLAN.
        See :class:`Vlan`.


        :param nsg_ids: The nsg_ids of this CreateVnicDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def private_ip(self):
        """
        Gets the private_ip of this CreateVnicDetails.
        A private IP address of your choice to assign to the VNIC. Must be an
        available IP address within the subnet's CIDR. If you don't specify a
        value, Oracle automatically assigns a private IP address from the subnet.
        This is the VNIC's *primary* private IP address. The value appears in
        the :class:`Vnic` object and also the
        :class:`PrivateIp` object returned by
        :func:`list_private_ips` and
        :func:`get_private_ip`.


        If you specify a `vlanId`, the `privateIp` cannot be specified.
        See :class:`Vlan`.

        Example: `10.0.3.3`


        :return: The private_ip of this CreateVnicDetails.
        :rtype: str
        """
        return self._private_ip

    @private_ip.setter
    def private_ip(self, private_ip):
        """
        Sets the private_ip of this CreateVnicDetails.
        A private IP address of your choice to assign to the VNIC. Must be an
        available IP address within the subnet's CIDR. If you don't specify a
        value, Oracle automatically assigns a private IP address from the subnet.
        This is the VNIC's *primary* private IP address. The value appears in
        the :class:`Vnic` object and also the
        :class:`PrivateIp` object returned by
        :func:`list_private_ips` and
        :func:`get_private_ip`.


        If you specify a `vlanId`, the `privateIp` cannot be specified.
        See :class:`Vlan`.

        Example: `10.0.3.3`


        :param private_ip: The private_ip of this CreateVnicDetails.
        :type: str
        """
        self._private_ip = private_ip

    @property
    def skip_source_dest_check(self):
        """
        Gets the skip_source_dest_check of this CreateVnicDetails.
        Whether the source/destination check is disabled on the VNIC.
        Defaults to `false`, which means the check is performed. For information
        about why you would skip the source/destination check, see
        `Using a Private IP as a Route Target`__.


        If you specify a `vlanId`, the `skipSourceDestCheck` cannot be specified because the
        source/destination check is always disabled for VNICs in a VLAN. See
        :class:`Vlan`.

        Example: `true`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip


        :return: The skip_source_dest_check of this CreateVnicDetails.
        :rtype: bool
        """
        return self._skip_source_dest_check

    @skip_source_dest_check.setter
    def skip_source_dest_check(self, skip_source_dest_check):
        """
        Sets the skip_source_dest_check of this CreateVnicDetails.
        Whether the source/destination check is disabled on the VNIC.
        Defaults to `false`, which means the check is performed. For information
        about why you would skip the source/destination check, see
        `Using a Private IP as a Route Target`__.


        If you specify a `vlanId`, the `skipSourceDestCheck` cannot be specified because the
        source/destination check is always disabled for VNICs in a VLAN. See
        :class:`Vlan`.

        Example: `true`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip


        :param skip_source_dest_check: The skip_source_dest_check of this CreateVnicDetails.
        :type: bool
        """
        self._skip_source_dest_check = skip_source_dest_check

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this CreateVnicDetails.
        The OCID of the subnet to create the VNIC in. When launching an instance,
        use this `subnetId` instead of the deprecated `subnetId` in
        :func:`launch_instance_details`.
        At least one of them is required; if you provide both, the values must match.

        If you are an Oracle Cloud VMware Solution customer and creating a secondary
        VNIC in a VLAN instead of a subnet, provide a `vlanId` instead of a `subnetId`.
        If you provide both a `vlanId` and `subnetId`, the request fails.


        :return: The subnet_id of this CreateVnicDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateVnicDetails.
        The OCID of the subnet to create the VNIC in. When launching an instance,
        use this `subnetId` instead of the deprecated `subnetId` in
        :func:`launch_instance_details`.
        At least one of them is required; if you provide both, the values must match.

        If you are an Oracle Cloud VMware Solution customer and creating a secondary
        VNIC in a VLAN instead of a subnet, provide a `vlanId` instead of a `subnetId`.
        If you provide both a `vlanId` and `subnetId`, the request fails.


        :param subnet_id: The subnet_id of this CreateVnicDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def vlan_id(self):
        """
        Gets the vlan_id of this CreateVnicDetails.
        Provide this attribute only if you are an Oracle Cloud VMware Solution
        customer and creating a secondary VNIC in a VLAN. The value is the OCID of the VLAN.
        See :class:`Vlan`.

        Provide a `vlanId` instead of a `subnetId`. If you provide both a
        `vlanId` and `subnetId`, the request fails.


        :return: The vlan_id of this CreateVnicDetails.
        :rtype: str
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """
        Sets the vlan_id of this CreateVnicDetails.
        Provide this attribute only if you are an Oracle Cloud VMware Solution
        customer and creating a secondary VNIC in a VLAN. The value is the OCID of the VLAN.
        See :class:`Vlan`.

        Provide a `vlanId` instead of a `subnetId`. If you provide both a
        `vlanId` and `subnetId`, the request fails.


        :param vlan_id: The vlan_id of this CreateVnicDetails.
        :type: str
        """
        self._vlan_id = vlan_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsField(object):
    """
    Field Details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsField object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cee_alias:
            The value to assign to the cee_alias property of this LogAnalyticsField.
        :type cee_alias: str

        :param data_type:
            The value to assign to the data_type property of this LogAnalyticsField.
        :type data_type: str

        :param regular_expression:
            The value to assign to the regular_expression property of this LogAnalyticsField.
        :type regular_expression: str

        :param description:
            The value to assign to the description property of this LogAnalyticsField.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsField.
        :type display_name: str

        :param edit_version:
            The value to assign to the edit_version property of this LogAnalyticsField.
        :type edit_version: int

        :param facet_priority:
            The value to assign to the facet_priority property of this LogAnalyticsField.
        :type facet_priority: int

        :param name:
            The value to assign to the name property of this LogAnalyticsField.
        :type name: str

        :param is_facet_eligible:
            The value to assign to the is_facet_eligible property of this LogAnalyticsField.
        :type is_facet_eligible: bool

        :param is_high_cardinality:
            The value to assign to the is_high_cardinality property of this LogAnalyticsField.
        :type is_high_cardinality: bool

        :param is_large_data:
            The value to assign to the is_large_data property of this LogAnalyticsField.
        :type is_large_data: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this LogAnalyticsField.
        :type is_multi_valued: bool

        :param is_primary:
            The value to assign to the is_primary property of this LogAnalyticsField.
        :type is_primary: bool

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsField.
        :type is_system: bool

        :param is_summarizable:
            The value to assign to the is_summarizable property of this LogAnalyticsField.
        :type is_summarizable: bool

        :param mapped_value:
            The value to assign to the mapped_value property of this LogAnalyticsField.
        :type mapped_value: str

        :param is_metric_key_eligible:
            The value to assign to the is_metric_key_eligible property of this LogAnalyticsField.
        :type is_metric_key_eligible: bool

        :param is_metric_value_eligible:
            The value to assign to the is_metric_value_eligible property of this LogAnalyticsField.
        :type is_metric_value_eligible: bool

        :param range_facet_eligible:
            The value to assign to the range_facet_eligible property of this LogAnalyticsField.
        :type range_facet_eligible: int

        :param is_table_eligible:
            The value to assign to the is_table_eligible property of this LogAnalyticsField.
        :type is_table_eligible: bool

        :param unit_type:
            The value to assign to the unit_type property of this LogAnalyticsField.
        :type unit_type: str

        """
        self.swagger_types = {
            'cee_alias': 'str',
            'data_type': 'str',
            'regular_expression': 'str',
            'description': 'str',
            'display_name': 'str',
            'edit_version': 'int',
            'facet_priority': 'int',
            'name': 'str',
            'is_facet_eligible': 'bool',
            'is_high_cardinality': 'bool',
            'is_large_data': 'bool',
            'is_multi_valued': 'bool',
            'is_primary': 'bool',
            'is_system': 'bool',
            'is_summarizable': 'bool',
            'mapped_value': 'str',
            'is_metric_key_eligible': 'bool',
            'is_metric_value_eligible': 'bool',
            'range_facet_eligible': 'int',
            'is_table_eligible': 'bool',
            'unit_type': 'str'
        }

        self.attribute_map = {
            'cee_alias': 'ceeAlias',
            'data_type': 'dataType',
            'regular_expression': 'regularExpression',
            'description': 'description',
            'display_name': 'displayName',
            'edit_version': 'editVersion',
            'facet_priority': 'facetPriority',
            'name': 'name',
            'is_facet_eligible': 'isFacetEligible',
            'is_high_cardinality': 'isHighCardinality',
            'is_large_data': 'isLargeData',
            'is_multi_valued': 'isMultiValued',
            'is_primary': 'isPrimary',
            'is_system': 'isSystem',
            'is_summarizable': 'isSummarizable',
            'mapped_value': 'mappedValue',
            'is_metric_key_eligible': 'isMetricKeyEligible',
            'is_metric_value_eligible': 'isMetricValueEligible',
            'range_facet_eligible': 'rangeFacetEligible',
            'is_table_eligible': 'isTableEligible',
            'unit_type': 'unitType'
        }

        self._cee_alias = None
        self._data_type = None
        self._regular_expression = None
        self._description = None
        self._display_name = None
        self._edit_version = None
        self._facet_priority = None
        self._name = None
        self._is_facet_eligible = None
        self._is_high_cardinality = None
        self._is_large_data = None
        self._is_multi_valued = None
        self._is_primary = None
        self._is_system = None
        self._is_summarizable = None
        self._mapped_value = None
        self._is_metric_key_eligible = None
        self._is_metric_value_eligible = None
        self._range_facet_eligible = None
        self._is_table_eligible = None
        self._unit_type = None

    @property
    def cee_alias(self):
        """
        Gets the cee_alias of this LogAnalyticsField.
        The name this field is given in the common event expression standard from mitre.org.
        This is used for reference when exporting content conforming to CEE standard


        :return: The cee_alias of this LogAnalyticsField.
        :rtype: str
        """
        return self._cee_alias

    @cee_alias.setter
    def cee_alias(self, cee_alias):
        """
        Sets the cee_alias of this LogAnalyticsField.
        The name this field is given in the common event expression standard from mitre.org.
        This is used for reference when exporting content conforming to CEE standard


        :param cee_alias: The cee_alias of this LogAnalyticsField.
        :type: str
        """
        self._cee_alias = cee_alias

    @property
    def data_type(self):
        """
        Gets the data_type of this LogAnalyticsField.
        The field data type.


        :return: The data_type of this LogAnalyticsField.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this LogAnalyticsField.
        The field data type.


        :param data_type: The data_type of this LogAnalyticsField.
        :type: str
        """
        self._data_type = data_type

    @property
    def regular_expression(self):
        """
        Gets the regular_expression of this LogAnalyticsField.
        The field default regular expression.


        :return: The regular_expression of this LogAnalyticsField.
        :rtype: str
        """
        return self._regular_expression

    @regular_expression.setter
    def regular_expression(self, regular_expression):
        """
        Sets the regular_expression of this LogAnalyticsField.
        The field default regular expression.


        :param regular_expression: The regular_expression of this LogAnalyticsField.
        :type: str
        """
        self._regular_expression = regular_expression

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsField.
        The field description.


        :return: The description of this LogAnalyticsField.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsField.
        The field description.


        :param description: The description of this LogAnalyticsField.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsField.
        The field display name.


        :return: The display_name of this LogAnalyticsField.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsField.
        The field display name.


        :param display_name: The display_name of this LogAnalyticsField.
        :type: str
        """
        self._display_name = display_name

    @property
    def edit_version(self):
        """
        Gets the edit_version of this LogAnalyticsField.
        The field edit version.


        :return: The edit_version of this LogAnalyticsField.
        :rtype: int
        """
        return self._edit_version

    @edit_version.setter
    def edit_version(self, edit_version):
        """
        Sets the edit_version of this LogAnalyticsField.
        The field edit version.


        :param edit_version: The edit_version of this LogAnalyticsField.
        :type: int
        """
        self._edit_version = edit_version

    @property
    def facet_priority(self):
        """
        Gets the facet_priority of this LogAnalyticsField.
        The facet priority.


        :return: The facet_priority of this LogAnalyticsField.
        :rtype: int
        """
        return self._facet_priority

    @facet_priority.setter
    def facet_priority(self, facet_priority):
        """
        Sets the facet_priority of this LogAnalyticsField.
        The facet priority.


        :param facet_priority: The facet_priority of this LogAnalyticsField.
        :type: int
        """
        self._facet_priority = facet_priority

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsField.
        The field internal name.


        :return: The name of this LogAnalyticsField.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsField.
        The field internal name.


        :param name: The name of this LogAnalyticsField.
        :type: str
        """
        self._name = name

    @property
    def is_facet_eligible(self):
        """
        Gets the is_facet_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the facet is elibigle for use.


        :return: The is_facet_eligible of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_facet_eligible

    @is_facet_eligible.setter
    def is_facet_eligible(self, is_facet_eligible):
        """
        Sets the is_facet_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the facet is elibigle for use.


        :param is_facet_eligible: The is_facet_eligible of this LogAnalyticsField.
        :type: bool
        """
        self._is_facet_eligible = is_facet_eligible

    @property
    def is_high_cardinality(self):
        """
        Gets the is_high_cardinality of this LogAnalyticsField.
        A flag inidcating whether or not the cardinality of the field is high.


        :return: The is_high_cardinality of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_high_cardinality

    @is_high_cardinality.setter
    def is_high_cardinality(self, is_high_cardinality):
        """
        Sets the is_high_cardinality of this LogAnalyticsField.
        A flag inidcating whether or not the cardinality of the field is high.


        :param is_high_cardinality: The is_high_cardinality of this LogAnalyticsField.
        :type: bool
        """
        self._is_high_cardinality = is_high_cardinality

    @property
    def is_large_data(self):
        """
        Gets the is_large_data of this LogAnalyticsField.
        A flag inidcating whether or not the field is a large data field.


        :return: The is_large_data of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_large_data

    @is_large_data.setter
    def is_large_data(self, is_large_data):
        """
        Sets the is_large_data of this LogAnalyticsField.
        A flag inidcating whether or not the field is a large data field.


        :param is_large_data: The is_large_data of this LogAnalyticsField.
        :type: bool
        """
        self._is_large_data = is_large_data

    @property
    def is_multi_valued(self):
        """
        Gets the is_multi_valued of this LogAnalyticsField.
        A flag indicating whether or not the field is multi-valued.


        :return: The is_multi_valued of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_multi_valued

    @is_multi_valued.setter
    def is_multi_valued(self, is_multi_valued):
        """
        Sets the is_multi_valued of this LogAnalyticsField.
        A flag indicating whether or not the field is multi-valued.


        :param is_multi_valued: The is_multi_valued of this LogAnalyticsField.
        :type: bool
        """
        self._is_multi_valued = is_multi_valued

    @property
    def is_primary(self):
        """
        Gets the is_primary of this LogAnalyticsField.
        A flag inidcating whether or not this is a primary field.


        :return: The is_primary of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_primary

    @is_primary.setter
    def is_primary(self, is_primary):
        """
        Sets the is_primary of this LogAnalyticsField.
        A flag inidcating whether or not this is a primary field.


        :param is_primary: The is_primary of this LogAnalyticsField.
        :type: bool
        """
        self._is_primary = is_primary

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsField.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :return: The is_system of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsField.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :param is_system: The is_system of this LogAnalyticsField.
        :type: bool
        """
        self._is_system = is_system

    @property
    def is_summarizable(self):
        """
        Gets the is_summarizable of this LogAnalyticsField.
        A flag inidcating whether or not the field can be summarized.


        :return: The is_summarizable of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_summarizable

    @is_summarizable.setter
    def is_summarizable(self, is_summarizable):
        """
        Sets the is_summarizable of this LogAnalyticsField.
        A flag inidcating whether or not the field can be summarized.


        :param is_summarizable: The is_summarizable of this LogAnalyticsField.
        :type: bool
        """
        self._is_summarizable = is_summarizable

    @property
    def mapped_value(self):
        """
        Gets the mapped_value of this LogAnalyticsField.
        The mapped value.


        :return: The mapped_value of this LogAnalyticsField.
        :rtype: str
        """
        return self._mapped_value

    @mapped_value.setter
    def mapped_value(self, mapped_value):
        """
        Sets the mapped_value of this LogAnalyticsField.
        The mapped value.


        :param mapped_value: The mapped_value of this LogAnalyticsField.
        :type: str
        """
        self._mapped_value = mapped_value

    @property
    def is_metric_key_eligible(self):
        """
        Gets the is_metric_key_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is metric key eligible.


        :return: The is_metric_key_eligible of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_metric_key_eligible

    @is_metric_key_eligible.setter
    def is_metric_key_eligible(self, is_metric_key_eligible):
        """
        Sets the is_metric_key_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is metric key eligible.


        :param is_metric_key_eligible: The is_metric_key_eligible of this LogAnalyticsField.
        :type: bool
        """
        self._is_metric_key_eligible = is_metric_key_eligible

    @property
    def is_metric_value_eligible(self):
        """
        Gets the is_metric_value_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is metric value eligible.


        :return: The is_metric_value_eligible of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_metric_value_eligible

    @is_metric_value_eligible.setter
    def is_metric_value_eligible(self, is_metric_value_eligible):
        """
        Sets the is_metric_value_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is metric value eligible.


        :param is_metric_value_eligible: The is_metric_value_eligible of this LogAnalyticsField.
        :type: bool
        """
        self._is_metric_value_eligible = is_metric_value_eligible

    @property
    def range_facet_eligible(self):
        """
        Gets the range_facet_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is range facet eligible.


        :return: The range_facet_eligible of this LogAnalyticsField.
        :rtype: int
        """
        return self._range_facet_eligible

    @range_facet_eligible.setter
    def range_facet_eligible(self, range_facet_eligible):
        """
        Sets the range_facet_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is range facet eligible.


        :param range_facet_eligible: The range_facet_eligible of this LogAnalyticsField.
        :type: int
        """
        self._range_facet_eligible = range_facet_eligible

    @property
    def is_table_eligible(self):
        """
        Gets the is_table_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is table eligible.


        :return: The is_table_eligible of this LogAnalyticsField.
        :rtype: bool
        """
        return self._is_table_eligible

    @is_table_eligible.setter
    def is_table_eligible(self, is_table_eligible):
        """
        Sets the is_table_eligible of this LogAnalyticsField.
        A flag inidcating whether or not the field is table eligible.


        :param is_table_eligible: The is_table_eligible of this LogAnalyticsField.
        :type: bool
        """
        self._is_table_eligible = is_table_eligible

    @property
    def unit_type(self):
        """
        Gets the unit_type of this LogAnalyticsField.
        The field unit type.


        :return: The unit_type of this LogAnalyticsField.
        :rtype: str
        """
        return self._unit_type

    @unit_type.setter
    def unit_type(self, unit_type):
        """
        Sets the unit_type of this LogAnalyticsField.
        The field unit type.


        :param unit_type: The unit_type of this LogAnalyticsField.
        :type: str
        """
        self._unit_type = unit_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlPlanLine(object):
    """
    SQL Plan Line type object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlPlanLine object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this SqlPlanLine.
        :type version: float

        :param sql_identifier:
            The value to assign to the sql_identifier property of this SqlPlanLine.
        :type sql_identifier: str

        :param plan_hash:
            The value to assign to the plan_hash property of this SqlPlanLine.
        :type plan_hash: int

        :param time_collected:
            The value to assign to the time_collected property of this SqlPlanLine.
        :type time_collected: datetime

        :param operation:
            The value to assign to the operation property of this SqlPlanLine.
        :type operation: str

        :param remark:
            The value to assign to the remark property of this SqlPlanLine.
        :type remark: str

        :param options:
            The value to assign to the options property of this SqlPlanLine.
        :type options: str

        :param object_node:
            The value to assign to the object_node property of this SqlPlanLine.
        :type object_node: str

        :param object_owner:
            The value to assign to the object_owner property of this SqlPlanLine.
        :type object_owner: str

        :param object_name:
            The value to assign to the object_name property of this SqlPlanLine.
        :type object_name: str

        :param object_alias:
            The value to assign to the object_alias property of this SqlPlanLine.
        :type object_alias: str

        :param object_instance:
            The value to assign to the object_instance property of this SqlPlanLine.
        :type object_instance: int

        :param object_type:
            The value to assign to the object_type property of this SqlPlanLine.
        :type object_type: str

        :param optimizer:
            The value to assign to the optimizer property of this SqlPlanLine.
        :type optimizer: str

        :param search_columns:
            The value to assign to the search_columns property of this SqlPlanLine.
        :type search_columns: int

        :param identifier:
            The value to assign to the identifier property of this SqlPlanLine.
        :type identifier: int

        :param parent_identifier:
            The value to assign to the parent_identifier property of this SqlPlanLine.
        :type parent_identifier: int

        :param depth:
            The value to assign to the depth property of this SqlPlanLine.
        :type depth: int

        :param position:
            The value to assign to the position property of this SqlPlanLine.
        :type position: int

        :param cost:
            The value to assign to the cost property of this SqlPlanLine.
        :type cost: int

        :param cardinality:
            The value to assign to the cardinality property of this SqlPlanLine.
        :type cardinality: int

        :param bytes:
            The value to assign to the bytes property of this SqlPlanLine.
        :type bytes: int

        :param other:
            The value to assign to the other property of this SqlPlanLine.
        :type other: str

        :param other_tag:
            The value to assign to the other_tag property of this SqlPlanLine.
        :type other_tag: str

        :param partition_start:
            The value to assign to the partition_start property of this SqlPlanLine.
        :type partition_start: str

        :param partition_stop:
            The value to assign to the partition_stop property of this SqlPlanLine.
        :type partition_stop: str

        :param partition_identifier:
            The value to assign to the partition_identifier property of this SqlPlanLine.
        :type partition_identifier: int

        :param distribution:
            The value to assign to the distribution property of this SqlPlanLine.
        :type distribution: str

        :param cpu_cost:
            The value to assign to the cpu_cost property of this SqlPlanLine.
        :type cpu_cost: int

        :param io_cost:
            The value to assign to the io_cost property of this SqlPlanLine.
        :type io_cost: int

        :param temp_space:
            The value to assign to the temp_space property of this SqlPlanLine.
        :type temp_space: int

        :param access_predicates:
            The value to assign to the access_predicates property of this SqlPlanLine.
        :type access_predicates: str

        :param filter_predicates:
            The value to assign to the filter_predicates property of this SqlPlanLine.
        :type filter_predicates: str

        :param projection:
            The value to assign to the projection property of this SqlPlanLine.
        :type projection: str

        :param qblock_name:
            The value to assign to the qblock_name property of this SqlPlanLine.
        :type qblock_name: str

        :param elapsed_time_in_sec:
            The value to assign to the elapsed_time_in_sec property of this SqlPlanLine.
        :type elapsed_time_in_sec: float

        :param other_xml:
            The value to assign to the other_xml property of this SqlPlanLine.
        :type other_xml: str

        """
        self.swagger_types = {
            'version': 'float',
            'sql_identifier': 'str',
            'plan_hash': 'int',
            'time_collected': 'datetime',
            'operation': 'str',
            'remark': 'str',
            'options': 'str',
            'object_node': 'str',
            'object_owner': 'str',
            'object_name': 'str',
            'object_alias': 'str',
            'object_instance': 'int',
            'object_type': 'str',
            'optimizer': 'str',
            'search_columns': 'int',
            'identifier': 'int',
            'parent_identifier': 'int',
            'depth': 'int',
            'position': 'int',
            'cost': 'int',
            'cardinality': 'int',
            'bytes': 'int',
            'other': 'str',
            'other_tag': 'str',
            'partition_start': 'str',
            'partition_stop': 'str',
            'partition_identifier': 'int',
            'distribution': 'str',
            'cpu_cost': 'int',
            'io_cost': 'int',
            'temp_space': 'int',
            'access_predicates': 'str',
            'filter_predicates': 'str',
            'projection': 'str',
            'qblock_name': 'str',
            'elapsed_time_in_sec': 'float',
            'other_xml': 'str'
        }

        self.attribute_map = {
            'version': 'version',
            'sql_identifier': 'sqlIdentifier',
            'plan_hash': 'planHash',
            'time_collected': 'timeCollected',
            'operation': 'operation',
            'remark': 'remark',
            'options': 'options',
            'object_node': 'objectNode',
            'object_owner': 'objectOwner',
            'object_name': 'objectName',
            'object_alias': 'objectAlias',
            'object_instance': 'objectInstance',
            'object_type': 'objectType',
            'optimizer': 'optimizer',
            'search_columns': 'searchColumns',
            'identifier': 'identifier',
            'parent_identifier': 'parentIdentifier',
            'depth': 'depth',
            'position': 'position',
            'cost': 'cost',
            'cardinality': 'cardinality',
            'bytes': 'bytes',
            'other': 'other',
            'other_tag': 'otherTag',
            'partition_start': 'partitionStart',
            'partition_stop': 'partitionStop',
            'partition_identifier': 'partitionIdentifier',
            'distribution': 'distribution',
            'cpu_cost': 'cpuCost',
            'io_cost': 'ioCost',
            'temp_space': 'tempSpace',
            'access_predicates': 'accessPredicates',
            'filter_predicates': 'filterPredicates',
            'projection': 'projection',
            'qblock_name': 'qblockName',
            'elapsed_time_in_sec': 'elapsedTimeInSec',
            'other_xml': 'otherXML'
        }

        self._version = None
        self._sql_identifier = None
        self._plan_hash = None
        self._time_collected = None
        self._operation = None
        self._remark = None
        self._options = None
        self._object_node = None
        self._object_owner = None
        self._object_name = None
        self._object_alias = None
        self._object_instance = None
        self._object_type = None
        self._optimizer = None
        self._search_columns = None
        self._identifier = None
        self._parent_identifier = None
        self._depth = None
        self._position = None
        self._cost = None
        self._cardinality = None
        self._bytes = None
        self._other = None
        self._other_tag = None
        self._partition_start = None
        self._partition_stop = None
        self._partition_identifier = None
        self._distribution = None
        self._cpu_cost = None
        self._io_cost = None
        self._temp_space = None
        self._access_predicates = None
        self._filter_predicates = None
        self._projection = None
        self._qblock_name = None
        self._elapsed_time_in_sec = None
        self._other_xml = None

    @property
    def version(self):
        """
        Gets the version of this SqlPlanLine.
        Version
        Example: `1`


        :return: The version of this SqlPlanLine.
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SqlPlanLine.
        Version
        Example: `1`


        :param version: The version of this SqlPlanLine.
        :type: float
        """
        self._version = version

    @property
    def sql_identifier(self):
        """
        **[Required]** Gets the sql_identifier of this SqlPlanLine.
        Unique SQL_ID for a SQL Statement.


        :return: The sql_identifier of this SqlPlanLine.
        :rtype: str
        """
        return self._sql_identifier

    @sql_identifier.setter
    def sql_identifier(self, sql_identifier):
        """
        Sets the sql_identifier of this SqlPlanLine.
        Unique SQL_ID for a SQL Statement.


        :param sql_identifier: The sql_identifier of this SqlPlanLine.
        :type: str
        """
        self._sql_identifier = sql_identifier

    @property
    def plan_hash(self):
        """
        **[Required]** Gets the plan_hash of this SqlPlanLine.
        Plan hash value for the SQL Execution Plan


        :return: The plan_hash of this SqlPlanLine.
        :rtype: int
        """
        return self._plan_hash

    @plan_hash.setter
    def plan_hash(self, plan_hash):
        """
        Sets the plan_hash of this SqlPlanLine.
        Plan hash value for the SQL Execution Plan


        :param plan_hash: The plan_hash of this SqlPlanLine.
        :type: int
        """
        self._plan_hash = plan_hash

    @property
    def time_collected(self):
        """
        **[Required]** Gets the time_collected of this SqlPlanLine.
        Collection time stamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :return: The time_collected of this SqlPlanLine.
        :rtype: datetime
        """
        return self._time_collected

    @time_collected.setter
    def time_collected(self, time_collected):
        """
        Sets the time_collected of this SqlPlanLine.
        Collection time stamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :param time_collected: The time_collected of this SqlPlanLine.
        :type: datetime
        """
        self._time_collected = time_collected

    @property
    def operation(self):
        """
        **[Required]** Gets the operation of this SqlPlanLine.
        Operation
        Example: `\"SELECT STATEMENT\"`


        :return: The operation of this SqlPlanLine.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this SqlPlanLine.
        Operation
        Example: `\"SELECT STATEMENT\"`


        :param operation: The operation of this SqlPlanLine.
        :type: str
        """
        self._operation = operation

    @property
    def remark(self):
        """
        Gets the remark of this SqlPlanLine.
        Remark
        Example: `\"\"`


        :return: The remark of this SqlPlanLine.
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """
        Sets the remark of this SqlPlanLine.
        Remark
        Example: `\"\"`


        :param remark: The remark of this SqlPlanLine.
        :type: str
        """
        self._remark = remark

    @property
    def options(self):
        """
        Gets the options of this SqlPlanLine.
        Options
        Example: `\"RANGE SCAN\"`


        :return: The options of this SqlPlanLine.
        :rtype: str
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this SqlPlanLine.
        Options
        Example: `\"RANGE SCAN\"`


        :param options: The options of this SqlPlanLine.
        :type: str
        """
        self._options = options

    @property
    def object_node(self):
        """
        Gets the object_node of this SqlPlanLine.
        Object Node
        Example: `\"Q4000\"`


        :return: The object_node of this SqlPlanLine.
        :rtype: str
        """
        return self._object_node

    @object_node.setter
    def object_node(self, object_node):
        """
        Sets the object_node of this SqlPlanLine.
        Object Node
        Example: `\"Q4000\"`


        :param object_node: The object_node of this SqlPlanLine.
        :type: str
        """
        self._object_node = object_node

    @property
    def object_owner(self):
        """
        Gets the object_owner of this SqlPlanLine.
        Object Owner
        Example: `\"TENANT_A#SCHEMA\"`


        :return: The object_owner of this SqlPlanLine.
        :rtype: str
        """
        return self._object_owner

    @object_owner.setter
    def object_owner(self, object_owner):
        """
        Sets the object_owner of this SqlPlanLine.
        Object Owner
        Example: `\"TENANT_A#SCHEMA\"`


        :param object_owner: The object_owner of this SqlPlanLine.
        :type: str
        """
        self._object_owner = object_owner

    @property
    def object_name(self):
        """
        Gets the object_name of this SqlPlanLine.
        Object Name
        Example: `\"PLAN_LINES_PK\"`


        :return: The object_name of this SqlPlanLine.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this SqlPlanLine.
        Object Name
        Example: `\"PLAN_LINES_PK\"`


        :param object_name: The object_name of this SqlPlanLine.
        :type: str
        """
        self._object_name = object_name

    @property
    def object_alias(self):
        """
        Gets the object_alias of this SqlPlanLine.
        Object Alias
        Example: `\"PLAN_LINES@SEL$1\"`


        :return: The object_alias of this SqlPlanLine.
        :rtype: str
        """
        return self._object_alias

    @object_alias.setter
    def object_alias(self, object_alias):
        """
        Sets the object_alias of this SqlPlanLine.
        Object Alias
        Example: `\"PLAN_LINES@SEL$1\"`


        :param object_alias: The object_alias of this SqlPlanLine.
        :type: str
        """
        self._object_alias = object_alias

    @property
    def object_instance(self):
        """
        Gets the object_instance of this SqlPlanLine.
        Object Instance
        Example: `37472`


        :return: The object_instance of this SqlPlanLine.
        :rtype: int
        """
        return self._object_instance

    @object_instance.setter
    def object_instance(self, object_instance):
        """
        Sets the object_instance of this SqlPlanLine.
        Object Instance
        Example: `37472`


        :param object_instance: The object_instance of this SqlPlanLine.
        :type: int
        """
        self._object_instance = object_instance

    @property
    def object_type(self):
        """
        Gets the object_type of this SqlPlanLine.
        Object Type
        Example: `\"INDEX (UNIQUE)\"`


        :return: The object_type of this SqlPlanLine.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this SqlPlanLine.
        Object Type
        Example: `\"INDEX (UNIQUE)\"`


        :param object_type: The object_type of this SqlPlanLine.
        :type: str
        """
        self._object_type = object_type

    @property
    def optimizer(self):
        """
        Gets the optimizer of this SqlPlanLine.
        Optimizer
        Example: `\"CLUSTER\"`


        :return: The optimizer of this SqlPlanLine.
        :rtype: str
        """
        return self._optimizer

    @optimizer.setter
    def optimizer(self, optimizer):
        """
        Sets the optimizer of this SqlPlanLine.
        Optimizer
        Example: `\"CLUSTER\"`


        :param optimizer: The optimizer of this SqlPlanLine.
        :type: str
        """
        self._optimizer = optimizer

    @property
    def search_columns(self):
        """
        Gets the search_columns of this SqlPlanLine.
        Search Columns
        Example: `3`


        :return: The search_columns of this SqlPlanLine.
        :rtype: int
        """
        return self._search_columns

    @search_columns.setter
    def search_columns(self, search_columns):
        """
        Sets the search_columns of this SqlPlanLine.
        Search Columns
        Example: `3`


        :param search_columns: The search_columns of this SqlPlanLine.
        :type: int
        """
        self._search_columns = search_columns

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this SqlPlanLine.
        Identifier
        Example: `3`


        :return: The identifier of this SqlPlanLine.
        :rtype: int
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this SqlPlanLine.
        Identifier
        Example: `3`


        :param identifier: The identifier of this SqlPlanLine.
        :type: int
        """
        self._identifier = identifier

    @property
    def parent_identifier(self):
        """
        Gets the parent_identifier of this SqlPlanLine.
        Parent Identifier
        Example: `2`


        :return: The parent_identifier of this SqlPlanLine.
        :rtype: int
        """
        return self._parent_identifier

    @parent_identifier.setter
    def parent_identifier(self, parent_identifier):
        """
        Sets the parent_identifier of this SqlPlanLine.
        Parent Identifier
        Example: `2`


        :param parent_identifier: The parent_identifier of this SqlPlanLine.
        :type: int
        """
        self._parent_identifier = parent_identifier

    @property
    def depth(self):
        """
        Gets the depth of this SqlPlanLine.
        Depth
        Example: `3`


        :return: The depth of this SqlPlanLine.
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """
        Sets the depth of this SqlPlanLine.
        Depth
        Example: `3`


        :param depth: The depth of this SqlPlanLine.
        :type: int
        """
        self._depth = depth

    @property
    def position(self):
        """
        Gets the position of this SqlPlanLine.
        Position
        Example: `1`


        :return: The position of this SqlPlanLine.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this SqlPlanLine.
        Position
        Example: `1`


        :param position: The position of this SqlPlanLine.
        :type: int
        """
        self._position = position

    @property
    def cost(self):
        """
        Gets the cost of this SqlPlanLine.
        Cost
        Example: `1`


        :return: The cost of this SqlPlanLine.
        :rtype: int
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """
        Sets the cost of this SqlPlanLine.
        Cost
        Example: `1`


        :param cost: The cost of this SqlPlanLine.
        :type: int
        """
        self._cost = cost

    @property
    def cardinality(self):
        """
        Gets the cardinality of this SqlPlanLine.
        Cardinality
        Example: `1`


        :return: The cardinality of this SqlPlanLine.
        :rtype: int
        """
        return self._cardinality

    @cardinality.setter
    def cardinality(self, cardinality):
        """
        Sets the cardinality of this SqlPlanLine.
        Cardinality
        Example: `1`


        :param cardinality: The cardinality of this SqlPlanLine.
        :type: int
        """
        self._cardinality = cardinality

    @property
    def bytes(self):
        """
        Gets the bytes of this SqlPlanLine.
        Bytes
        Example: `150`


        :return: The bytes of this SqlPlanLine.
        :rtype: int
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes):
        """
        Sets the bytes of this SqlPlanLine.
        Bytes
        Example: `150`


        :param bytes: The bytes of this SqlPlanLine.
        :type: int
        """
        self._bytes = bytes

    @property
    def other(self):
        """
        Gets the other of this SqlPlanLine.
        Other
        Example: ``


        :return: The other of this SqlPlanLine.
        :rtype: str
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this SqlPlanLine.
        Other
        Example: ``


        :param other: The other of this SqlPlanLine.
        :type: str
        """
        self._other = other

    @property
    def other_tag(self):
        """
        Gets the other_tag of this SqlPlanLine.
        Other Tag
        Example: `\"PARALLEL_COMBINED_WITH_PARENT\"`


        :return: The other_tag of this SqlPlanLine.
        :rtype: str
        """
        return self._other_tag

    @other_tag.setter
    def other_tag(self, other_tag):
        """
        Sets the other_tag of this SqlPlanLine.
        Other Tag
        Example: `\"PARALLEL_COMBINED_WITH_PARENT\"`


        :param other_tag: The other_tag of this SqlPlanLine.
        :type: str
        """
        self._other_tag = other_tag

    @property
    def partition_start(self):
        """
        Gets the partition_start of this SqlPlanLine.
        Partition start
        Example: `1`


        :return: The partition_start of this SqlPlanLine.
        :rtype: str
        """
        return self._partition_start

    @partition_start.setter
    def partition_start(self, partition_start):
        """
        Sets the partition_start of this SqlPlanLine.
        Partition start
        Example: `1`


        :param partition_start: The partition_start of this SqlPlanLine.
        :type: str
        """
        self._partition_start = partition_start

    @property
    def partition_stop(self):
        """
        Gets the partition_stop of this SqlPlanLine.
        Partition stop
        Example: `2`


        :return: The partition_stop of this SqlPlanLine.
        :rtype: str
        """
        return self._partition_stop

    @partition_stop.setter
    def partition_stop(self, partition_stop):
        """
        Sets the partition_stop of this SqlPlanLine.
        Partition stop
        Example: `2`


        :param partition_stop: The partition_stop of this SqlPlanLine.
        :type: str
        """
        self._partition_stop = partition_stop

    @property
    def partition_identifier(self):
        """
        Gets the partition_identifier of this SqlPlanLine.
        Partition identifier
        Example: `8`


        :return: The partition_identifier of this SqlPlanLine.
        :rtype: int
        """
        return self._partition_identifier

    @partition_identifier.setter
    def partition_identifier(self, partition_identifier):
        """
        Sets the partition_identifier of this SqlPlanLine.
        Partition identifier
        Example: `8`


        :param partition_identifier: The partition_identifier of this SqlPlanLine.
        :type: int
        """
        self._partition_identifier = partition_identifier

    @property
    def distribution(self):
        """
        Gets the distribution of this SqlPlanLine.
        Distribution
        Example: `\"QC (RANDOM)\"`


        :return: The distribution of this SqlPlanLine.
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """
        Sets the distribution of this SqlPlanLine.
        Distribution
        Example: `\"QC (RANDOM)\"`


        :param distribution: The distribution of this SqlPlanLine.
        :type: str
        """
        self._distribution = distribution

    @property
    def cpu_cost(self):
        """
        Gets the cpu_cost of this SqlPlanLine.
        CPU cost
        Example: `7321`


        :return: The cpu_cost of this SqlPlanLine.
        :rtype: int
        """
        return self._cpu_cost

    @cpu_cost.setter
    def cpu_cost(self, cpu_cost):
        """
        Sets the cpu_cost of this SqlPlanLine.
        CPU cost
        Example: `7321`


        :param cpu_cost: The cpu_cost of this SqlPlanLine.
        :type: int
        """
        self._cpu_cost = cpu_cost

    @property
    def io_cost(self):
        """
        Gets the io_cost of this SqlPlanLine.
        IO cost
        Example: `1`


        :return: The io_cost of this SqlPlanLine.
        :rtype: int
        """
        return self._io_cost

    @io_cost.setter
    def io_cost(self, io_cost):
        """
        Sets the io_cost of this SqlPlanLine.
        IO cost
        Example: `1`


        :param io_cost: The io_cost of this SqlPlanLine.
        :type: int
        """
        self._io_cost = io_cost

    @property
    def temp_space(self):
        """
        Gets the temp_space of this SqlPlanLine.
        Time space
        Example: `15614000`


        :return: The temp_space of this SqlPlanLine.
        :rtype: int
        """
        return self._temp_space

    @temp_space.setter
    def temp_space(self, temp_space):
        """
        Sets the temp_space of this SqlPlanLine.
        Time space
        Example: `15614000`


        :param temp_space: The temp_space of this SqlPlanLine.
        :type: int
        """
        self._temp_space = temp_space

    @property
    def access_predicates(self):
        """
        Gets the access_predicates of this SqlPlanLine.
        Access predicates
        Example: `\"\\\"RESOURCE_ID\\\"=:1 AND \\\"QUERY_ID\\\"=:2\"`


        :return: The access_predicates of this SqlPlanLine.
        :rtype: str
        """
        return self._access_predicates

    @access_predicates.setter
    def access_predicates(self, access_predicates):
        """
        Sets the access_predicates of this SqlPlanLine.
        Access predicates
        Example: `\"\\\"RESOURCE_ID\\\"=:1 AND \\\"QUERY_ID\\\"=:2\"`


        :param access_predicates: The access_predicates of this SqlPlanLine.
        :type: str
        """
        self._access_predicates = access_predicates

    @property
    def filter_predicates(self):
        """
        Gets the filter_predicates of this SqlPlanLine.
        Filter predicates
        Example: `\"(INTERNAL_FUNCTION(\\\"J\\\".\\\"DATABASE_ROLE\\\") OR (\\\"J\\\".\\\"DATABASE_ROLE\\\" IS NULL AND SYS_CONTEXT('userenv','database_role')='PRIMARY'))\"`


        :return: The filter_predicates of this SqlPlanLine.
        :rtype: str
        """
        return self._filter_predicates

    @filter_predicates.setter
    def filter_predicates(self, filter_predicates):
        """
        Sets the filter_predicates of this SqlPlanLine.
        Filter predicates
        Example: `\"(INTERNAL_FUNCTION(\\\"J\\\".\\\"DATABASE_ROLE\\\") OR (\\\"J\\\".\\\"DATABASE_ROLE\\\" IS NULL AND SYS_CONTEXT('userenv','database_role')='PRIMARY'))\"`


        :param filter_predicates: The filter_predicates of this SqlPlanLine.
        :type: str
        """
        self._filter_predicates = filter_predicates

    @property
    def projection(self):
        """
        Gets the projection of this SqlPlanLine.
        Projection
        Example: `\"COUNT(*)[22]\"`


        :return: The projection of this SqlPlanLine.
        :rtype: str
        """
        return self._projection

    @projection.setter
    def projection(self, projection):
        """
        Sets the projection of this SqlPlanLine.
        Projection
        Example: `\"COUNT(*)[22]\"`


        :param projection: The projection of this SqlPlanLine.
        :type: str
        """
        self._projection = projection

    @property
    def qblock_name(self):
        """
        Gets the qblock_name of this SqlPlanLine.
        Qblock Name
        Example: `\"SEL$1\"`


        :return: The qblock_name of this SqlPlanLine.
        :rtype: str
        """
        return self._qblock_name

    @qblock_name.setter
    def qblock_name(self, qblock_name):
        """
        Sets the qblock_name of this SqlPlanLine.
        Qblock Name
        Example: `\"SEL$1\"`


        :param qblock_name: The qblock_name of this SqlPlanLine.
        :type: str
        """
        self._qblock_name = qblock_name

    @property
    def elapsed_time_in_sec(self):
        """
        Gets the elapsed_time_in_sec of this SqlPlanLine.
        Total elapsed time
        Example: `1.2`


        :return: The elapsed_time_in_sec of this SqlPlanLine.
        :rtype: float
        """
        return self._elapsed_time_in_sec

    @elapsed_time_in_sec.setter
    def elapsed_time_in_sec(self, elapsed_time_in_sec):
        """
        Sets the elapsed_time_in_sec of this SqlPlanLine.
        Total elapsed time
        Example: `1.2`


        :param elapsed_time_in_sec: The elapsed_time_in_sec of this SqlPlanLine.
        :type: float
        """
        self._elapsed_time_in_sec = elapsed_time_in_sec

    @property
    def other_xml(self):
        """
        Gets the other_xml of this SqlPlanLine.
        Other SQL
        Example: `\"<other_xml><info type=\\\"db_version\\\">18.0.0.0</info><info type=\\\"parse_schema\\\"><![CDATA[\\\"SYS\\\"]]></info><info type=\\\"plan_hash_full\\\">483892784</info><info type=\\\"plan_hash\\\">2709293936</info><info type=\\\"plan_hash_2\\\">483892784</info><outline_data><hint><![CDATA[IGNORE_OPTIM_EMBEDDED_HINTS]]></hint><hint><![CDATA[OPTIMIZER_FEATURES_ENABLE('18.1.0')]]></hint><hint><![CDATA[DB_VERSION('18.1.0')]]></hint><hint><![CDATA[OPT_PARAM('_b_tree_bitmap_plans' 'false')]]></hint><hint><![CDATA[OPT_PARAM('_optim_peek_user_binds' 'false')]]></hint><hint><![CDATA[OPT_PARAM('result_cache_mode' 'FORCE')]]></hint><hint><![CDATA[OPT_PARAM('_fix_control' '20648883:0 27745220:1 30001331:1 30142527:1 30539126:1')]]></hint><hint><![CDATA[OUTLINE_LEAF(@\\\"SEL$1\\\")]]></hint><hint><![CDATA[INDEX(@\\\"SEL$1\\\" \\\"USER$\\\"@\\\"SEL$1\\\" \\\"I_USER#\\\")]]></hint></outline_data></other_xml>\"`


        :return: The other_xml of this SqlPlanLine.
        :rtype: str
        """
        return self._other_xml

    @other_xml.setter
    def other_xml(self, other_xml):
        """
        Sets the other_xml of this SqlPlanLine.
        Other SQL
        Example: `\"<other_xml><info type=\\\"db_version\\\">18.0.0.0</info><info type=\\\"parse_schema\\\"><![CDATA[\\\"SYS\\\"]]></info><info type=\\\"plan_hash_full\\\">483892784</info><info type=\\\"plan_hash\\\">2709293936</info><info type=\\\"plan_hash_2\\\">483892784</info><outline_data><hint><![CDATA[IGNORE_OPTIM_EMBEDDED_HINTS]]></hint><hint><![CDATA[OPTIMIZER_FEATURES_ENABLE('18.1.0')]]></hint><hint><![CDATA[DB_VERSION('18.1.0')]]></hint><hint><![CDATA[OPT_PARAM('_b_tree_bitmap_plans' 'false')]]></hint><hint><![CDATA[OPT_PARAM('_optim_peek_user_binds' 'false')]]></hint><hint><![CDATA[OPT_PARAM('result_cache_mode' 'FORCE')]]></hint><hint><![CDATA[OPT_PARAM('_fix_control' '20648883:0 27745220:1 30001331:1 30142527:1 30539126:1')]]></hint><hint><![CDATA[OUTLINE_LEAF(@\\\"SEL$1\\\")]]></hint><hint><![CDATA[INDEX(@\\\"SEL$1\\\" \\\"USER$\\\"@\\\"SEL$1\\\" \\\"I_USER#\\\")]]></hint></outline_data></other_xml>\"`


        :param other_xml: The other_xml of this SqlPlanLine.
        :type: str
        """
        self._other_xml = other_xml

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
